@@ -1,5 +1,5 @@
 #!/usr/bin/python
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
-__all__ = ['main']
+__all__ = ['command_url', 'command_share']
 import main
